==> haskell-test-framework-leancheck-0.0.4-109-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-test-framework-leancheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 test-framework-leancheck
version:              0.0.4
visibility:           public
id:                   test-framework-leancheck-0.0.4-55SkksKYXTAFPX8kmnWx9G
key:                  test-framework-leancheck-0.0.4-55SkksKYXTAFPX8kmnWx9G
license:              BSD-3-Clause
maintainer:           Rudy Matela <rudy@matela.com.br>
author:               Rudy Matela <rudy@matela.com.br>
homepage:
    https://github.com/rudymatela/test-framework-leancheck#readme

synopsis:             LeanCheck support for test-framework.
description:
    LeanCheck support for test-framework.

    This package can be used to incorporate LeanCheck tests
    into test-framework test suites.

    Please see the Haddock documentation and README for more details.

category:             Testing
abi:                  39da156b6a5bdf951cf4c44987ff207a
exposed:              True
exposed-modules:      Test.Framework.Providers.LeanCheck
import-dirs:
    /usr/lib/ghc-9.2.8/site-local/test-framework-leancheck-0.0.4

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/test-framework-leancheck-0.0.4

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-test-framework-leancheck
hs-libraries:         HStest-framework-leancheck-0.0.4-55SkksKYXTAFPX8kmnWx9G
depends:
    base-4.16.4.0 leancheck-1.0.2-HIaoH79TY3JkwPqecWynF
    test-framework-0.8.2.0-30XOAxDTBtoHUhSfJhyDW8

haddock-interfaces:
    /usr/share/doc/haskell-test-framework-leancheck/html/test-framework-leancheck.haddock

haddock-html:         /usr/share/doc/haskell-test-framework-leancheck/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-test-framework-leancheck-0.0.4-111-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-test-framework-leancheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 test-framework-leancheck
version:              0.0.4
visibility:           public
id:                   test-framework-leancheck-0.0.4-D7b1MiZAD2qD80s3OX1UpK
key:                  test-framework-leancheck-0.0.4-D7b1MiZAD2qD80s3OX1UpK
license:              BSD-3-Clause
maintainer:           Rudy Matela <rudy@matela.com.br>
author:               Rudy Matela <rudy@matela.com.br>
homepage:
    https://github.com/rudymatela/test-framework-leancheck#readme

synopsis:             LeanCheck support for test-framework.
description:
    LeanCheck support for test-framework.

    This package can be used to incorporate LeanCheck tests
    into test-framework test suites.

    Please see the Haddock documentation and README for more details.

category:             Testing
abi:                  719632468cae9e6b4fa58e841c35cd49
exposed:              True
exposed-modules:      Test.Framework.Providers.LeanCheck
import-dirs:
    /usr/lib/ghc-9.2.8/site-local/test-framework-leancheck-0.0.4

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/test-framework-leancheck-0.0.4

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-test-framework-leancheck
hs-libraries:         HStest-framework-leancheck-0.0.4-D7b1MiZAD2qD80s3OX1UpK
depends:
    base-4.16.4.0 leancheck-1.0.2-HIaoH79TY3JkwPqecWynF
    test-framework-0.8.2.0-5uvP7zRH3Y54oipi1F1CKa

haddock-interfaces:
    /usr/share/doc/haskell-test-framework-leancheck/html/test-framework-leancheck.haddock

haddock-html:         /usr/share/doc/haskell-test-framework-leancheck/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
